==> runtime-simulator-0.6.0.tgz: package/src/polyfills/fetch.test.ts <==
/**
 * @license
 * Copyright 2022 Dynatrace LLC
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ContextConfiguration } from '../../lib';

const mockFetch = jest.fn();
jest.mock('node-fetch', () => {
  return {
    default: mockFetch,
    Request: jest.requireActual('node-fetch').Request,
  };
});

// eslint-disable-next-line import/first
import fetch from './fetch';

afterEach(() => {
  jest.clearAllMocks();
});

test('should handle URLs with a hostname', async () => {
  const environmentUrl = 'https://environment.localhost.test';
  const bearerToken = 'my-token';
  const config: ContextConfiguration = {
    appId: 'id',
    appName: 'name',
    environmentUrl: environmentUrl,
    token: bearerToken,
  };

  fetch(process.cwd(), environmentUrl, config)('http://localhost.test');

  expect(mockFetch).toHaveBeenCalledTimes(1);
  expect(mockFetch).toHaveBeenCalledWith('http://localhost.test', {});
});

test('should handle absolute URLs', async () => {
  const environmentUrl = 'https://environment.localhost.test';
  const bearerToken = 'my-token';
  const config: ContextConfiguration = {
    appId: 'id',
    appName: 'name',
    environmentUrl: environmentUrl,
    token: bearerToken,
  };

  fetch(process.cwd(), environmentUrl, config)('/a');

  const url = new URL(environmentUrl);
  url.pathname = '/a';

  expect(mockFetch).toHaveBeenCalledTimes(1);
  expect(mockFetch).toHaveBeenCalledWith(
    url.toString(),
    expect.objectContaining({
      headers: {
        authorization: `Bearer ${bearerToken}`,
        'Dt-App-Context': 'local-dev-mode',
        'Dt-Dev-Context': 'id',
        'Dt-Dev-App-Id': 'id',
      },
    }),
  );
});

==> runtime-simulator-0.9.1.tgz: package/src/polyfills/fetch.test.ts <==
/**
 * @license
 * Copyright 2022 Dynatrace LLC
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { ContextConfiguration } from '../../lib';

const mockFetch = jest.fn();
jest.mock('undici', () => {
  return {
    fetch: mockFetch,
    Request: jest.requireActual('undici').Request,
    Headers: jest.requireActual('undici').Headers,
  };
});

// eslint-disable-next-line import/first
import fetch from './fetch';
// eslint-disable-next-line import/first
import { Headers } from 'undici';

afterEach(() => {
  jest.clearAllMocks();
});

test('should handle URLs with a hostname', async () => {
  const environmentUrl = 'https://environment.localhost.test';
  const bearerToken = 'my-token';
  const config: ContextConfiguration = {
    appId: 'id',
    appName: 'name',
    environmentUrl: environmentUrl,
    token: bearerToken,
  };

  fetch(process.cwd(), environmentUrl, config)('http://localhost.test');

  expect(mockFetch).toHaveBeenCalledTimes(1);
  expect(mockFetch).toHaveBeenCalledWith('http://localhost.test', {});
});

test('should handle absolute URLs', async () => {
  const environmentUrl = 'https://environment.localhost.test';
  const bearerToken = 'my-token';
  const config: ContextConfiguration = {
    appId: 'id',
    appName: 'name',
    environmentUrl: environmentUrl,
    token: bearerToken,
  };

  fetch(process.cwd(), environmentUrl, config)('/a');

  const url = new URL(environmentUrl);
  url.pathname = '/a';

  expect(mockFetch).toHaveBeenCalledTimes(1);
  expect(mockFetch.mock.calls[0]);
  expect(mockFetch).toHaveBeenCalledWith(
    url.toString(),
    expect.objectContaining({
      headers: new Headers({
        authorization: `Bearer ${bearerToken}`,
        'Dt-App-Context': 'local-dev-mode',
        'Dt-Dev-Context': 'id',
        'Dt-Dev-App-Id': 'id',
      }),
    }),
  );
});

test('should fail when attempting to manually set internal Dt-* headers', () => {
  const environmentUrl = 'https://environment.localhost.test';
  const bearerToken = 'my-token';
  const config: ContextConfiguration = {
    appId: 'id',
    appName: 'name',
    environmentUrl: environmentUrl,
    token: bearerToken,
  };

  const testFetch = fetch(process.cwd(), environmentUrl, config);
  expect(() =>
    testFetch('/a', { headers: { 'Dt-App-Context': 'foobar' } }),
  ).toThrow(
    "Forbidden request: Header 'dt-app-context' not allowed in request",
  );

  expect(() =>
    testFetch('/a', { headers: { 'dt-app-context': 'foobar' } }),
  ).toThrow(
    "Forbidden request: Header 'dt-app-context' not allowed in request",
  );

  expect(() =>
    testFetch('/a', { headers: { 'Dt-Dev-App-Id': 'foobar' } }),
  ).toThrow("Forbidden request: Header 'dt-dev-app-id' not allowed in request");

  expect(() =>
    testFetch('/a', { headers: { 'dt-dev-app-id': 'foobar' } }),
  ).toThrow("Forbidden request: Header 'dt-dev-app-id' not allowed in request");

  expect(() =>
    testFetch('/a', { headers: { 'Dt-Dev-Context': 'foobar' } }),
  ).toThrow(
    "Forbidden request: Header 'dt-dev-context' not allowed in request",
  );

  expect(() =>
    testFetch('/a', { headers: { 'dt-dev-context': 'foobar' } }),
  ).toThrow(
    "Forbidden request: Header 'dt-dev-context' not allowed in request",
  );
});
